/*
 * Based on code that contains the following:
 *
 *  (c) Copyright Hewlett-Packard Company 2001 
 *  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 * * $Id: StatementHandler.java,v 1.1 2001/09/17 11:12:52 jjc Exp $
   
   ORIGINAL AUTHOR:  Jeremy J. Carroll
   MODIFIED BY: David Rager
*/
/*
 * LocationStatementHandler.java
 *
 * Created on August 20, 2002, 5:45 PM
 */

package com.hp.hpl.jena.rdf.arp;

/** The callback from a reader to an RDF application.
 * Each triple in the input file causes a call on one of the statement methods.
 * The same triple may occur more than once in a file, causing repeat calls
 * to the method.
 * Modified the original StatementHandler to take an additonal Location object
 * for the statement that records where the statement is defined in the source file.
 *
 * @author jjc
 */
public interface LocationStatementHandler extends StatementHandler  {

/** A triple in the file.
 * @param subj The subject.
 * @param pred The property.
 * @param obj The object.
 * @param loc The location for the statement.
 */    
   public void statement(AResource subj, AResource pred, AResource obj, Location loc );
/** A triple in the file.
 * @param subj The subject.
 * @param pred The property.
 * @param lit The object.
 * @param loc The location for the statement.
 */    
   public void statement(AResource subj, AResource pred, ALiteral lit, Location loc );

}
